@@ -1,5 +1,5 @@
 #
-# $Id: Search.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
+# $Id: Search.pm,v eff9afda3723 2015/01/04 12:34:23 gomor $
 #
 # brik::search Brik
 #
@@ -11,8 +11,8 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1cdea52670de $',
-      tags => [ qw(unstable) ],
+      revision => '$Revision: eff9afda3723 $',
+      tags => [ qw(unstable main brik search) ],
       commands => {
          all => [ ],
          string => [ qw(string) ],
@@ -20,8 +20,6 @@ sub brik_properties {
          not_tag => [ qw(Tag) ],
          used => [ ],
          not_used => [ ],
-         show_require_modules => [ ],
-         command => [ qw(Command) ],
       },
    };
 }
@@ -60,7 +58,9 @@ sub string {
    my $self = shift;
    my ($string) = @_;
 
-   $self->brik_help_run_undef_arg('string', $string) or return;
+   if (! defined($string)) {
+      return $self->log->error($self->brik_help_run('string'));
+   }
 
    my $context = $self->context;
    my $status = $context->status;
@@ -89,7 +89,9 @@ sub tag {
    my $self = shift;
    my ($tag) = @_;
 
-   $self->brik_help_run_undef_arg('tag', $tag) or return;
+   if (! defined($tag)) {
+      return $self->log->error($self->brik_help_run('tag'));
+   }
 
    my $context = $self->context;
    my $status = $context->status;
@@ -127,7 +129,9 @@ sub not_tag {
    my $self = shift;
    my ($tag) = @_;
 
-   $self->brik_help_run_undef_arg('not_tag', $tag) or return;
+   if (! defined($tag)) {
+      return $self->log->error($self->brik_help_run('not_tag'));
+   }
 
    my $context = $self->context;
    my $status = $context->status;
@@ -172,76 +176,6 @@ sub not_used {
    return $self->not_tag('used');
 }
 
-sub show_require_modules {
-   my $self = shift;
-
-   my $context = $self->context;
-   my $available = $context->available;
-
-   # Don't show require for Core modules
-   my $core = {
-      'core::context',
-      'core::log',
-      'core::shell',
-      'core::global',
-   };
-
-   my %require_modules = ();
-   for my $brik (keys %$available) {
-      next if (exists($core->{$brik}));
-      if ($available->{$brik}->can('brik_properties')) {
-         my $modules = $available->{$brik}->brik_properties->{require_modules};
-         for my $module (keys %$modules) {
-            next if $module =~ /^Metabrik/;
-            $require_modules{$module} = $brik;
-         }
-      }
-   }
-
-   return [ sort { $a cmp $b } keys %require_modules ];
-}
-
-sub command {
-   my $self = shift;
-   my ($command) = @_;
-
-   $self->brik_help_run_undef_arg('command', $command) or return;
-
-   my $context = $self->context;
-   my $status = $context->status;
-
-   my $total = 0;
-   $self->log->info("Used:");
-   for my $brik (@{$status->{used}}) {
-      if (exists($context->used->{$brik}->brik_properties->{commands})) {
-         my $tags = $context->used->{$brik}->brik_tags;
-         push @$tags, 'used';
-         for my $key (keys %{$context->used->{$brik}->brik_properties->{commands}}) {
-            if ($key =~ /$command/i) {
-               $self->log->info(sprintf("   %-20s [%s]", $brik, join(', ', @$tags)));
-               $total++;
-            }
-         }
-      }
-   }
-
-   $self->log->info("Not used:");
-   for my $brik (@{$status->{not_used}}) {
-      if (exists($context->not_used->{$brik}->brik_properties->{commands})) {
-         my $tags = $context->not_used->{$brik}->brik_tags;
-         push @$tags, 'not_used';
-         for my $key (keys %{$context->not_used->{$brik}->brik_properties->{commands}}) {
-            if ($key =~ /$command/i) {
-               $self->log->info(sprintf("   %-20s [%s]", $brik, join(', ', @$tags)));
-               $total++;
-            }
-         }
-      }
-   }
-
-   return $total;
-}
-
 1;
 
 __END__
@@ -252,7 +186,7 @@ Metabrik::Brik::Search - brik::search Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
