@@ -1,5 +1,5 @@
 #
-# $Id: Csv.pm 360 2014-11-16 14:52:06Z gomor $
+# $Id: Csv.pm,v eff9afda3723 2015/01/04 12:34:23 gomor $
 #
 # file::csv Brik
 #
@@ -11,19 +11,24 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 360 $',
+      revision => '$Revision: eff9afda3723 $',
       tags => [ qw(unstable csv file) ],
       attributes => {
          input => [ qw(file) ],
          output => [ qw(file) ],
-         has_header => [ qw(0|1) ],
-         format => [ qw(aoh|hoh) ],
+         first_line_is_header => [ qw(0|1) ],
          separator => [ qw(character) ],
          header => [ qw($column_header_list) ],
-         key => [ qw(key) ],
          encoding => [ qw(utf8|ascii) ],
          overwrite => [ qw(0|1) ],
       },
+      attributes_default => {
+         first_line_is_header => 1,
+         header => [ ],
+         separator => ';',
+         encoding => 'utf8',
+         overwrite => 1,
+      },
       commands => {
          read => [ qw(input_file|OPTIONAL) ],
          write => [ qw(csv_struct output_file|OPTIONAL) ],
@@ -31,10 +36,9 @@ sub brik_properties {
          get_col_by_number => [ qw($data|$READ integer) ],
       },
       require_modules => {
-         'Text::CSV::Hashify' => [ ],
-      },
-      require_used => {
-         'file::write' => [ ],
+         'Text::CSV' => [ ],
+         'Metabrik::File::Read' => [ ],
+         'Metabrik::File::Write' => [ ],
       },
    };
 }
@@ -44,14 +48,8 @@ sub brik_use_properties {
 
    return {
       attributes_default => {
-         input => $self->global->input || '/tmp/input.txt',
-         output => $self->global->output || '/tmp/output.txt',
-         has_header => 0,
-         header => [ ],
-         format => 'aoh',
-         separator => ';',
-         encoding => 'utf8',
-         overwrite => 1,
+         input => $self->global->input,
+         output => $self->global->output,
       },
    };
 }
@@ -61,26 +59,55 @@ sub read {
    my ($input) = @_;
 
    $input ||= $self->input;
-
    if (! defined($input)) {
       return $self->log->error($self->brik_help_set('input'));
    }
 
-   my $format = $self->format;
-   if ($format !~ /^aoh$/ && $format !~ /^hoh$/) {
-      return $self->log->error($self->brik_help_set('format'));
+   my $csv = Text::CSV->new({
+      binary => 1,
+      sep_char => $self->separator,
+      allow_loose_quotes => 1,
+      allow_loose_escapes => 1,
+   }) or return $self->log->error('read: Text::CSV new failed');
+
+   my $read = Metabrik::File::Read->new_from_brik($self);
+   $read->encoding($self->encoding);
+   my $fd = $read->open($input)
+      or return $self->log->error('read: read failed');
+
+   my $sep = $self->separator;
+   my $headers;
+   my $count;
+   my $first_line = 1;
+   my @rows = ();
+   while (my $row = $csv->getline($fd)) {
+      if ($self->first_line_is_header) {
+         if ($first_line) {  # This is first line
+            $headers = $row;
+            $count = scalar @$row - 1;
+            $first_line = 0;
+            next;
+         }
+
+         my $h;
+         for (0..$count) {
+            $h->{$headers->[$_]} = $row->[$_];
+         }
+         push @rows, $h;
+      }
+      else {
+         push @rows, $row;
+      }
    }
 
-   my $key = $self->key;
+   if (! $csv->eof) {
+      my $error_str = "".$csv->error_diag();
+      return $self->log->error("read: $error_str");
+   }
 
-   my $data = Text::CSV::Hashify->new({
-      file => $input,
-      format => $format,
-      sep_char => $self->separator,
-      key => $key,
-   }) or return $self->log->error("Text::CSV::Hashify: new");
+   $read->close;
 
-   return $data->all;
+   return \@rows;
 }
 
 sub write {
@@ -108,17 +135,24 @@ sub write {
 
    my $context = $self->context;
 
-   $context->save_state('file::write') or return;
-
-   $context->set('file::write', 'output', $output) or return;
-   my $fd = $context->run('file::write', 'open') or return;
+   my $write = Metabrik::File::Write->new_from_brik($self);
+   $write->output($output);
+   $write->encoding($self->encoding);
+   my $fd = $write->open
+      or return $self->log->error('write: open failed');
 
    my $written = '';
 
    my $header_written = 0;
+   my %order = ();
    for my $this (@$csv_struct) {
       if (! $header_written) {
-         my @header = keys %$this;
+         my $idx = 0;
+         for my $k (sort { $a cmp $b } keys %$this) {
+            $order{$k} = $idx;
+            $idx++;
+         }
+         my @header = sort { $a cmp $b } keys %$this;
          my $data = join($self->separator, @header)."\n";
          print $fd $data;
          $written .= $data;
@@ -126,17 +160,26 @@ sub write {
       }
 
       my @fields = ();
-      for my $key (keys %$this) {
-         push @fields, $this->{$key};
+      for my $key (sort { $a cmp $b } keys %$this) {
+         $fields[$order{$key}] = $this->{$key};
       }
+
       my $data = join($self->separator, @fields)."\n";
-      print $fd $data;
+
+      my $r = $write->write($data);
+      if (! defined($r)) {
+         $self->log->error("write: write failed");
+         next;
+      }
+
       $written .= $data;
    }
 
-   $context->run('file::write', 'close');
+   $write->close;
 
-   $context->restore_state('file::write');
+   if (! length($written)) {
+      return $self->log->error("write: nothing to write");
+   }
 
    return $written;
 }
@@ -145,22 +188,20 @@ sub get_col_by_name {
    my $self = shift;
    my ($data, $type, $value) = @_;
 
-   if (! $self->has_header || @{$self->header} == 0) {
-      return $self->log->error("CSV has no header, can't do that");
-   }
-
    if (! defined($data)) {
-      return $self->log->error($self->brik_help_run('read'));
+      return $self->log->error($self->brik_help_run('get_col_by_name'));
    }
-
    if (! defined($type)) {
       return $self->log->error($self->brik_help_run('get_col_by_name'));
    }
-
    if (! defined($value)) {
       return $self->log->error($self->brik_help_run('get_col_by_name'));
    }
 
+   if (! $self->first_line_is_header || @{$self->header} == 0) {
+      return $self->log->error("get_col_by_name: no CSV header found");
+   }
+
    my @results = ();
    for my $row (@$data) {
       if (exists($row->{$type})) {
@@ -190,7 +231,7 @@ Metabrik::File::Csv - file::csv Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
