@@ -1,5 +1,5 @@
 #
-# $Id: Netbios.pm 363 2014-11-16 15:36:29Z gomor $
+# $Id: Netbios.pm,v eff9afda3723 2015/01/04 12:34:23 gomor $
 #
 # network::netbios Brik
 #
@@ -11,10 +11,10 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 363 $',
+      revision => '$Revision: eff9afda3723 $',
       tags => [ qw(unstable netbios) ],
       commands => {
-         nodestatus => [ qw(ipv4_address) ],
+         probe => [ qw(ipv4_address) ],
       },
       require_modules => {
          'Net::NBName' => [ ],
@@ -22,12 +22,12 @@ sub brik_properties {
    };
 }
 
-sub nodestatus {
+sub probe {
    my $self = shift;
    my ($ip) = @_;
 
    if (! defined($ip)) {
-      return $self->log->error($self->brik_help_run('nodestatus'));
+      return $self->log->error($self->brik_help_run('probe'));
    }
 
    my $nb = Net::NBName->new;
@@ -37,6 +37,19 @@ sub nodestatus {
 
    my $ns = $nb->node_status($ip);
    if ($ns) {
+      #for my $rr ($ns->names) {
+          #if ($rr->suffix == 0 && $rr->G eq "GROUP") {
+              #$domain = $rr->name;
+          #}
+          #if ($rr->suffix == 3 && $rr->G eq "UNIQUE") {
+              #$user = $rr->name;
+          #}
+          #if ($rr->suffix == 0 && $rr->G eq "UNIQUE") {
+              #$machine = $rr->name unless $rr->name =~ /^IS~/;
+          #}
+      #}
+      #$mac_address = $ns->mac_address;
+      #print "$mac_address $domain\\$machine $user";
       print $ns->as_string;
       return $nb;
    }
@@ -56,7 +69,7 @@ Metabrik::Network::Netbios - network::netbios Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
