@@ -1,5 +1,5 @@
 #
-# $Id: Read.pm,v 1cdea52670de 2016/01/02 17:14:57 gomor $
+# $Id: Read.pm,v eff9afda3723 2015/01/04 12:34:23 gomor $
 #
 # network::read Brik
 #
@@ -11,10 +11,8 @@ use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 1cdea52670de $',
-      tags => [ qw(unstable ethernet ip raw socket) ],
-      author => 'GomoR <GomoR[at]metabrik.org>',
-      license => 'http://opensource.org/licenses/BSD-3-Clause',
+      revision => '$Revision: eff9afda3723 $',
+      tags => [ qw(unstable network read ethernet ip raw socket) ],
       attributes => {
          device => [ qw(device) ],
          rtimeout => [ qw(seconds) ],
@@ -22,22 +20,17 @@ sub brik_properties {
          protocol => [ qw(tcp|udp) ],
          layer => [ qw(2|3|4) ],
          filter => [ qw(pcap_filter) ],
-         count => [ qw(count) ],
+         max_read => [ qw(integer_packet_count) ],
          _dump => [ qw(INTERNAL) ],
       },
       attributes_default => {
          layer => 2,
-         count => 0,
-         family => 'ipv4',
-         protocol => 'tcp',
-         rtimeout => 5,
-         filter => '',
+         max_read => 0,
       },
       commands => {
-         open => [ qw(layer|OPTIONAL device|OPTIONAL filter|OPTIONAL) ],
-         read => [ ],
-         read_next => [ qw(count) ],
-         read_until_timeout => [ qw(count timeout|OPTIONAL) ],
+         open => [ qw(layer|OPTIONAL arg2|OPTIONAL arg3|OPTIONAL) ],
+         next => [ ],
+         next_until_timeout => [ ],
          close => [ ],
          has_timeout => [ ],
          reset_timeout => [ ],
@@ -55,109 +48,84 @@ sub brik_use_properties {
 
    return {
       attributes_default => {
+         rtimeout => $self->global->rtimeout,
          device => $self->global->device,
+         family => $self->global->family,
+         protocol => $self->global->protocol,
       },
    };
 }
 
 sub open {
    my $self = shift;
-   my ($layer, $device, $filter) = @_;
-
-   $self->brik_help_run_must_be_root('open') or return;
+   my ($layer, $arg2, $arg3) = @_;
 
    $layer ||= 2;
-   $device ||= $self->device;
-   $filter ||= $self->filter;
 
    my $family = $self->family eq 'ipv6' ? 'ip6' : 'ip';
 
    my $protocol = defined($self->protocol) ? $self->protocol : 'tcp';
 
+   my $filter = $self->filter || '';
+
    my $dump;
    if ($layer == 2) {
+      $arg2 ||= $self->device;
+      $arg3 ||= $filter;
+
       $self->debug && $self->log->debug("open: timeoutOnNext: ".$self->rtimeout);
       $self->debug && $self->log->debug("open: filter: ".$filter);
 
       $dump = Net::Frame::Dump::Online2->new(
-         dev => $device,
+         dev => $arg2,
          timeoutOnNext => $self->rtimeout,
-         filter => $filter,
-      ) or return $self->log->error("open: Net::Frame::Dump::Online2->new failed");
+         filter => $arg3,
+      );
    }
    elsif ($self->layer != 3) {
       return $self->log->error("open: not implemented");
    }
 
-   $dump->start or return $self->log->error("open: Net::Frame::Dump::Online2->start failed");
+   $dump->start or return $self->log->error("open: error");
 
    return $self->_dump($dump);
 }
 
-sub read {
+sub next {
    my $self = shift;
 
    my $dump = $self->_dump;
-   $self->brik_help_run_undef_arg('open', $dump) or return;
+   if (! defined($dump)) {
+      return $self->log->error($self->brik_help_run('open'));
+   }
+
+   my $next = $dump->next;
+
+   return defined($next) ? $next : 0;
+}
+
+sub next_until_timeout {
+   my $self = shift;
+
+   my $dump = $self->_dump;
+   if (! defined($dump)) {
+      return $self->log->error($self->brik_help_run('open'));
+   }
+
+   my $rtimeout = $self->rtimeout;
+   my $max_read = $self->max_read;
+   $self->log->verbose("next_until_timeout: will read until $rtimeout seconds timeout or $max_read max read packet(s) has been read");
 
-   my @next = ();
    my $count = 0;
-   while (my $next = $dump->next) {
-      $self->log->verbose("read: read ".++$count." packet(s)");
-      if (ref($next) eq 'ARRAY') {
-         push @next, @$next;
-      }
-      else {
-         push @next, $next;
-      }
-   }
-
-   return \@next;
-}
-
-sub read_next {
-   my $self = shift;
-   my ($count) = @_;
-
-   $count ||= $self->count;
-   my $dump = $self->_dump;
-   $self->brik_help_run_undef_arg('open', $dump) or return;
-
-   my @next = ();
-   my $read_count = 0;
-   while (1) {
-      my $next = $dump->next;
-      if (defined($next)) {
-         $self->log->verbose("read_next: read ".++$read_count." packet(s)");
-         push @next, $next;
-         last if ++$read_count == $count;
-      }
-   }
-
-   return \@next;
-}
-
-sub read_until_timeout {
-   my $self = shift;
-   my ($count, $rtimeout) = @_;
-
-   $count ||= $self->count;
-   $rtimeout ||= $self->rtimeout;
-   my $dump = $self->_dump;
-   $self->brik_help_run_undef_arg('open', $dump) or return;
-
-   $self->debug && $self->log->debug("next_until_timeout: will read until $rtimeout seconds timeout or $count packet(s) has been read");
-
-   my $read_count = 0;
    my @next = ();
    while (! $dump->timeout) {
-      if ($count && $read_count == $count) {
+      if ($max_read && $count == $max_read) {
          last;
       }
 
       if (my $next = $dump->next) {
-         $self->log->verbose("read_until_timeout: read ".++$read_count." packet(s)");
          push @next, $next;
+         $self->debug && $self->log->debug("next_until_timeout: read one packet");
          $count++;
       }
    }
@@ -169,10 +137,18 @@ sub reply {
    my $self = shift;
    my ($frame) = @_;
 
+   if (! defined($frame)) {
+      return $self->log->error($self->brik_help_run('reply'));
+   }
+
+   if (ref($frame) ne 'Net::Frame::Simple') {
+      return $self->log->error("reply: frame must be Net::Frame::Simple object");
+   }
+
    my $dump = $self->_dump;
-   $self->brik_help_run_undef_arg('open', $dump) or return;
-   $self->brik_help_run_undef_arg('reply', $frame) or return;
-   $self->brik_help_run_invalid_arg('reply', $frame, 'Net::Frame::Simple') or return;
+   if (! defined($dump)) {
+      return $self->log->error($self->brik_help_run('open'));
+   }
 
    return $dump->getFramesFor($frame);
 }
@@ -229,7 +205,7 @@ Metabrik::Network::Read - network::read Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014-2016, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
