@@ -1,5 +1,5 @@
 #
-# $Id: Screenshot.pm 360 2014-11-16 14:52:06Z gomor $
+# $Id: Screenshot.pm,v eff9afda3723 2015/01/04 12:34:23 gomor $
 #
 # xorg::screenshot Brik
 #
@@ -7,11 +7,11 @@ package Metabrik::Xorg::Screenshot;
 use strict;
 use warnings;
 
-use base qw(Metabrik);
+use base qw(Metabrik::Shell::Command);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 360 $',
+      revision => '$Revision: eff9afda3723 $',
       tags => [ qw(unstable screenshot) ],
       attributes => {
          output => [ qw(file) ],
@@ -20,11 +20,8 @@ sub brik_properties {
          output => 'screenshot.png',
       },
       commands => {
-         active_window => [ ],
-         full_screen => [ ],
-      },
-      require_used => {
-         'shell::command' => [ ],
+         active_window => [ qw(output_file|OPTIONAL) ],
+         full_screen => [ qw(output_file|OPTIONAL) ],
       },
       require_binaries => {
          'scrot' => [ ],
@@ -34,26 +31,30 @@ sub brik_properties {
 
 sub active_window {
    my $self = shift;
+   my ($output) = @_;
 
-   my $output = $self->output;
-   my $context = $self->context;
+   $output ||= $self->output;
 
-   $self->log->verbose("Saving to file [$output]");
+   $self->log->verbose("active_window: saving to file [$output]");
 
    my $cmd = "scrot --focused --border $output";
-   return $context->run('shell::command', 'system', $cmd);
+   $self->system($cmd);
+
+   return $output;
 }
 
 sub full_screen {
    my $self = shift;
+   my ($output) = @_;
 
-   my $output = $self->output;
-   my $context = $self->context;
+   $output ||= $self->output;
 
-   $self->log->verbose("Saving to file [$output]");
+   $self->log->verbose("full_screen: saving to file [$output]");
 
    my $cmd = "scrot $output";
-   return $context->run('shell::command', 'system', $cmd);
+   $self->system($cmd);
+
+   return $output;
 }
 
 1;
@@ -66,7 +67,7 @@ Metabrik::Xorg::Screenshot - xorg::screenshot Brik
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2014, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
